SessionAuthRequestResponse class

Constructors

SessionAuthRequestResponse({required int id, required String pairingTopic, required Completer<SessionAuthResponse> completer, Uri? uri})

Properties

completer → Completer<SessionAuthResponse>
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
pairingTopic → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited